/*    callrec is a program that records calls on an openmoko.
 *    Copyright (C) 2009  Tom Hacohen (tom@stosb.com)
 *
 *    This file is a part of callrec
 * 
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtk/gtk.h>

#include <sys/signal.h>
#include <wait.h>

#include "ui_functions.h"
#include "recording.h"

#define GLADE_FILE "/usr/share/callrec/callrec.glade"

static int register_signal_handling(void);


/* FIXME: hack, should fix! */
/* Needed by the signal handler */
static GtkButton *btn_play = NULL;
static GtkButton *btn_record = NULL;

int 
main(int argc, char *argv[]) 
{
	GtkBuilder      *builder;
        GtkWidget       *window;
        
	register_signal_handling();
	
	gtk_init (&argc, &argv);
        
        builder = gtk_builder_new ();
	printf("Loading gtkbuilder file: %s\n", GLADE_FILE);
        gtk_builder_add_from_file (builder, GLADE_FILE, NULL);
 
        window = GTK_WIDGET (gtk_builder_get_object (builder, "main"));
	btn_record = (GtkButton *) gtk_builder_get_object (builder, "btn_record");
	btn_play = (GtkButton *) gtk_builder_get_object (builder, "btn_play");
	
	/* init and ref the non default ones */
	ui_init_button_widgets((GtkWidget *) gtk_builder_get_object (builder, "img_play"),
			       gtk_widget_ref((GtkWidget *) gtk_builder_get_object (builder, "img_stop_play")),
			       gtk_widget_ref((GtkWidget *) gtk_builder_get_object (builder, "img_stop_record")),
			       (GtkWidget *) gtk_builder_get_object (builder, "img_record")
			       );
        
	gtk_builder_connect_signals (builder, NULL);          
        g_object_unref (G_OBJECT (builder));
        
        gtk_widget_show_all (window);       
        gtk_main ();
        
	
	/*clean up*/
	stop_recording();
	stop_playing();
	
        return 0;
}

/*****************************
 * signal handling functions *
 *****************************/
static void
zombie_reaper (int signal)
{
	pid_t pid;
	enum ActionType action;
	(void) signal;
	while((pid = waitpid(-1, NULL, WNOHANG)) > 0) {
		action = whois_pid(pid);
		switch (action) {
			case ACTION_PLAY:
				stop_playing();
				ui_play_update(btn_play);
				break;
			case ACTION_RECORD:
				stop_recording();
				ui_record_update(btn_record, btn_play);
				break;
			default:
				break;
		}
	}
}

/**
 * register_signal_handling() - registers all the signal handlers
 *
 * This function registers the signal handlers for the system signals.
 *
 * Returns 0 on success, -ERR on error.
 **/
static int
register_signal_handling(void)
{
	struct sigaction signal_handling;
	/* init the other signal handlers */
	/* init the zombie reaper */
	signal_handling.sa_handler = zombie_reaper;
	sigemptyset(&signal_handling.sa_mask);
	signal_handling.sa_flags = SA_RESTART;
	if (sigaction(SIGCHLD, &signal_handling, NULL) != 0) {
		perror("sigaction");
		return -1;
	}
	
	
	
	return 0;
	
}
