/*    callrec is a program that records calls on an openmoko.
 *    Copyright (C) 2009  Tom Hacohen (tom@stosb.com)
 *
 *    This file is a part of callrec
 * 
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <gtk/gtk.h>

#include "ui_functions.h"
#include "recording.h"

/* the widgets to be used on the buttons */
static GtkWidget *_wid_play=NULL;
static GtkWidget *_wid_stop_play=NULL;
static GtkWidget *_wid_stop_record=NULL;
static GtkWidget *_wid_record=NULL;

/**
 * ui_init_button_widgets() - inits the button widgets.
 * @play:	        The play button's widget.
 * @stop_play:		The play button's stop widget.
 * @stop_record:	The recording button's stop widget.
 * @record:		The recording button's widget.
 *
 * This function initializes the widgets to be used inside the button in every
 * possible situation. For instance when recording, we want the button to be set
 * to stop_record.
 **/
void
ui_init_button_widgets(GtkWidget *play, GtkWidget *stop_play, GtkWidget *stop_record, GtkWidget *record)
{
	_wid_play = play;
	_wid_stop_record = stop_record;
	_wid_stop_play = stop_play;
	_wid_record = record;
}

/**
 * ui_record_update() - updates the record button's shown widget.
 * @record:		The recording button
 * @play:	        The play button
 *
 **/
void
ui_record_update(GtkButton *record, GtkButton *play)
{
	/* the current state, 0 is undefined 1 is on 2 is off */
	static int state = 0;
	
	/* if it's playing, and the last state is different than the current. */
	if (is_recording() && state != 1) {
		gtk_widget_ref(_wid_record);
		gtk_button_set_image(record, _wid_stop_record);
		gtk_widget_set_sensitive((GtkWidget *) play, FALSE);
		state = 1;
	}
	else if (! is_recording() && state != 2){
		gtk_widget_ref(_wid_stop_record);
		gtk_button_set_image(record, _wid_record);
		/* we can enable playback */
		gtk_widget_set_sensitive((GtkWidget *) play, TRUE);
		state = 2;
	}
}

/**
 * ui_play_update() - updates the record button's shown widget.
 * @play:	        The play button
 *
 * This function updates the ui to conform to the new state.
 **/
void
ui_play_update(GtkButton *play)
{
	/* the current state, 0 is undefined 1 is on 2 is off */
	static int state = 0;
	
	/* if it's playing, and the last state is different than the current. */
	if (is_playing() && state != 1) {
		gtk_widget_ref(_wid_play);
		gtk_button_set_image(play, _wid_stop_play);
		state = 1;
	}
	else if (! is_playing() && state != 2) {
		gtk_widget_ref(_wid_stop_play);
		gtk_button_set_image(play, _wid_play);
		state = 2;
	}
}